% plots spectrum of pulse train using GUI

[object,figure]=gcbo;
handles=guihandles(figure);

% get parameters
count=get(handles.count,'String');
To=get(handles.period,'String');
d=get(handles.dcycle,'String');
dc=get(handles.dcoff,'String');
tau=get(handles.delay,'String');
K=get(handles.nterms,'String');
To=str2num(To);

% save handles if first time program is executed
if str2num(count)==0
    handles1=handles;
    set(handles.count,'String','1');
end

% convert parameters from strings to numbers
d=str2num(d);
dc=str2num(dc);
tau=str2num(tau);
K=str2num(K);

% compute coefficients
fs=K*50/To;
k=-K:K;
f=k/To;
t=0:1/fs:3*To-1/fs;
ck=d*sinc(k*d).*exp(-j*2*pi*f*tau);
ck(K+1)=dc;
[x,t]=sumcos(f,ck,fs,3*To);

% plot signal
axes(handles.axes1);
plot(t,x);
title('Signal');
xlabel('Time (sec)');
ylabel('Amplitude');
high=max(x);
low=min(x);
axis([0,3*To,1.2*low,1.2*high]);
grid on;

% compute magnitude and phase of coefficients
ckmag=abs(ck);
ckphase=angle(ck);
ckphase=ckphase.*(ckmag>1e-5);

% compute magnitude envelope
fenv=-K/To:1/fs:K/To;
env=d*sinc(d*To*fenv);

% plot magnitude spectrum and envelope
axes(handles1.axes2);
spectpltmod(ckmag,f);
hold on;
plot(fenv,abs(env),':');
hold off;
title('Magnitude Spectrum');
xlabel('Frequency (Hz)');
ylabel('Magnitude');
grid on;

% plot phase spectrum
axes(handles.axes3);
spectpltmod(180/pi*ckphase,f);
title('Phase Spectrum');
xlabel('Frequency (Hz)');
ylabel('Phase (deg)');
grid on;